# SBMLDiagrams
[![Coverage](https://codecov.io/gh/sunnyXu/SBMLDiagrams/branch/main/graph/badge.svg)](https://codecov.io/gh/sunnyXu/SBMLDiagrams)

## Introduction
SBMLDiagrams can visualize SBML to PNG/JPG/PDF files by visualizeSBML. It also supports users to import, edit or export an SBML file. This package supports SBML level 3, including layout and render. In detail, it does not only provide position, size and color information for different graphical objects but also supports different shapes of nodes or alias nodes. If you use any part of this python package, please cite the Gihub website (https://github.com/SunnyXu/SBMLDiagrams).

## Installation

``pip install SBMLDiagrams``

## Documentation
Please see documentation at https://sunnyxu.github.io/SBMLDiagrams/ for details.


